This crate contains kube-rs compatible bindings for Kubernetes custom resources for the nativestor.alauda.io group. Each binding is generated with kopium, updated and released weekly.
Available Custom Resources
nativestor.alauda.io/v1
RawDevice